pub struct CloseForumTopic {
pub chat_id: ChatId,
pub message_thread_id: i64,
}Expand description
Use this method to close an open topic in a forum supergroup chat. The bot must be an administrator in the chat for this to work and must have the can_manage_topics administrator rights, unless it is the creator of the topic. Returns True on success.
Fields
chat_id: ChatIdUnique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)
message_thread_id: i64Unique identifier for the target message thread of the forum topic
Implementations