pub struct MessageEntity {
pub type_: String,
pub offset: i64,
pub length: i64,
pub url: Option<String>,
pub user: Option<User>,
pub language: Option<String>,
pub custom_emoji_id: Option<String>,
}Expand description
This object represents one special entity in a text message. For example, hashtags, usernames, URLs, etc.
Fields
type_: StringType of the entity. Currently, can be “mention” (@username), “hashtag” (#hashtag), “cashtag” ($USD), “bot_command” (/start@jobs_bot), “url” (https://telegram.org), “email” (do-not-reply@telegram.org), “phone_number” (+1-212-555-0123), “bold” (bold text), “italic” (italic text), “underline” (underlined text), “strikethrough” (strikethrough text), “spoiler” (spoiler message), “code” (monowidth string), “pre” (monowidth block), “text_link” (for clickable text URLs), “text_mention” (for users without usernames), “custom_emoji” (for inline custom emoji stickers)
offset: i64Offset in UTF-16 code units to the start of the entity
length: i64Length of the entity in UTF-16 code units
url: Option<String>For “text_link” only, URL that will be opened after user taps on the text
user: Option<User>For “text_mention” only, the mentioned user
language: Option<String>For “pre” only, the programming language of the entity text
custom_emoji_id: Option<String>For “custom_emoji” only, unique identifier of the custom emoji. Use getCustomEmojiStickers to get full information about the sticker
Implementations
Sourceimpl MessageEntity
impl MessageEntity