pub struct PassportElementErrorFile {
pub type_: String,
pub file_hash: String,
pub message: String,
}Expand description
Represents an issue with a document scan. The error is considered resolved when the file with the document scan changes.
Fields
type_: StringThe section of the user’s Telegram Passport which has the issue, one of “utility_bill”, “bank_statement”, “rental_agreement”, “passport_registration”, “temporary_registration”
file_hash: StringBase64-encoded file hash
message: StringError message
Implementations