pub struct UnhideGeneralForumTopic {
pub chat_id: ChatId,
}Expand description
Use this method to unhide the ‘General’ topic in a forum supergroup chat. The bot must be an administrator in the chat for this to work and must have the can_manage_topics administrator rights. Returns True on success.
Fields
chat_id: ChatIdUnique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)
Implementations