pub struct ChatJoinRequest {
pub chat: Chat,
pub from: User,
pub user_chat_id: i64,
pub date: i64,
pub bio: Option<String>,
pub invite_link: Option<ChatInviteLink>,
}Expand description
Represents a join request sent to a chat.
Fields
chat: ChatChat to which the request was sent
from: UserUser that sent the join request
user_chat_id: i64Identifier of a private chat with the user who sent the join request. This number may have more than 32 significant bits and some programming languages may have difficulty/silent defects in interpreting it. But it has at most 52 significant bits, so a 64-bit integer or double-precision float type are safe for storing this identifier. The bot can use this identifier for 24 hours to send messages until the join request is processed, assuming no other administrator contacted the user.
date: i64Date the request was sent in Unix time
bio: Option<String>Bio of the user.
invite_link: Option<ChatInviteLink>Chat invite link that was used by the user to send the join request